@@ -7,13 +7,20 @@ class Command(BaseCommand):
 
     help = "Promotes the named users to an admin superuser."
 
-    args = "[username, ...]"
+    def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
+        parser.add_argument(
+            "usernames",
+            metavar="usernames",
+            nargs="*",
+            help="Usernames to promote to admin superuser.",
+        )
 
     @transaction.atomic()
-    def handle(self, *usernames, **kwargs):
-        verbosity = int(kwargs.get("verbosity", 1))
+    def handle(self, **kwargs):
+        verbosity = kwargs["verbosity"]
         User = get_user_model()
-        for username in usernames:
+        for username in kwargs["usernames"]:
             try:
                 user = User.objects.get(username=username)
             except User.DoesNotExist:
